pub enum EqualityOperator {
    Lte,
    Lt,
    Gte,
    Gt,
    Eq,
    Ne,
}
An equality operator is used for testing two expressions. These expressions should be valid expressions according to the Kconfig grammar.

Variants

Lte

Lesser than or equal to (<=)

Lt

Greater than or equal to (>=)

Gte

Lesser than (<)

Gt

Greater than (>)

Eq

Equal to (==)

Ne

Not equal to (!=)