Lexicon

Enum Lexicon 

pub enum Lexicon {
Show 17 variants Keyword(Keyword), Identifier(String), String(String), Help(String), EqualityOperator(EqualityOperator), ImmediateAssignment, Assignment, AppendAssignment, Not, MacroOpen, Open, Close, Comma, EOT, Error(String), And, Or,
}
There are a certain amount of basic tokens found within a stream of tokens belonging to a Kconfig configuration specification. These tokens are outlined here.

Variants



Keyword(Keyword)

Keywords such as config, menuconfig, if, comment, source …



Identifier(String)

Identifier, specifically used for assignment and evaluation



String(String)

Strings, encapsulated in double quotes



Help(String)

Help text, indented when a “Help” section was started



EqualityOperator(EqualityOperator)

An equality operator, such as <=, ==, etc.



ImmediateAssignment

An immediate assignment, e.g.: :=



Assignment

A normal assignment, e.g.: =



AppendAssignment

An appendage assignment, e.g.: +=



Not

An inverse of an expression



MacroOpen

Start a macro definition with “$(”



Open

Start a normal definition with “(”



Close

Ends a definition (either macro or normal) with “)”



Comma

A comma, typically used as an argument separator



EOT

End of transmission, used when no more tokens can be found



Error(String)

Error, used when the found token is illegal



And

The ‘&&’ expression



Or

The ‘||’ expression