Module kconfig_parser::ast::parser
source · [−]Expand description
This file contains the parser of the Kconfig file, and creates the Abstract Syntax Tree for it.
Structs
Determines which config element type to use, this can either be Config or Menuconfig. Contains the Ast for the entire stream of tokens, including sourced elements.
Enums
An Ast contains a list of elements, which might themselves contain other parts of the Ast, etc.